package
Version:
v0.0.0-...-005ee03
Opens a new window with list of versions in this module.
Published: Oct 18, 2020
License: ISC
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package ndnparse parses NDN packets and extracts names.
Parse parses NDN packets.
type Packet struct {
Timestamp int64 `json:"timestamp"`
Name ndn.Name `json:"name"`
Type string `json:"type"`
}
Packet contains information about an NDN packet.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.